@@ -12,7 +12,7 @@ use List::MoreUtils qw(any firstidx);
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.31_07';
+our $VERSION = '0.33_01';
 $VERSION = eval $VERSION;    ## no critic
 
 #######
@@ -266,7 +266,7 @@ sub xtests_eval {
 sub _mod_ver {
 	my ($self, $modules, $version_strings, $eval_include) = @_;
 
-	if ($eval_include =~ /^\s*[use|require|no]/) {
+	if ($eval_include =~ /^\s*(?:use|require|no)/) {
 
 		$eval_include =~ s/^\s*(?:use|require|no)\s*//;
 
@@ -283,12 +283,13 @@ sub _mod_ver {
 		return if $self->{found_version}{$module_name};
 
 		# check for first char upper in module name
-		push @{$modules}, $module_name if $module_name =~ m/\A(?:[A-Z])/;
+		push @{$modules}, $module_name if $module_name =~ m{\A(?:[a-zA-Z])};
+
 
 		my $version_string = $eval_include;
 		$version_string =~ s/$module_name\s*//;
 		$version_string =~ s/\s*$//;
-		$version_string =~ s/[A-Z_a-z]|\s|\$|s|:|;//g;
+		$version_string =~ s/[a-zA-Z]|\s|\$|s|:|;//g;
 
 		$version_string = version::is_lax($version_string) ? $version_string : 0;
 		push @{$version_strings}, $version_string;
@@ -359,7 +360,7 @@ App::Midgen::Roles::Eval - used by L<App::Midgen>
 
 =head1 VERSION
 
-This document describes App::Midgen::Roles version: 0.31_07
+This document describes App::Midgen::Roles version: 0.33_01
 
 =head1 METHODS
 
